| example_data | R Documentation |
A simulated dataset containing an OTU table (ASV counts) and corresponding
group labels. The data are intended to illustrate the usage of the
fit_ncm function.
example_data
A list with two components:
A data frame with 15 rows (samples) and 2000 columns (ASVs). Row names are sample identifiers, column names are ASV identifiers. Values represent counts of each ASV in each sample.
A data frame with 15 rows and 1 column named group.
Row names correspond to the samples in otu. The group
column contains character labels ("A", "A", ..., etc.) indicating
group membership for each sample.
Simulated data for package examples.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.